@@ -8,9 +8,12 @@ import struct
 from PyQt4.QtCore import QCoreApplication, QDir, QFile, QIODevice, QStringList
 
 dictionaryFile = QDir.homePath() + '/.osso/dictionaries/.personal.dictionary'
-posPaddingOffset = 5
-posEntryCount    = 12
-posEntryStart    = 16
+positions      = {
+    'PaddingOffset': 6,
+    'Unknown': 9,
+    'EntryCount': 12,
+    'EntryStart': 16
+}
 
 class ACEFileException(Exception): #{{{1
     def __init__(self, msgsource, errmsg):
@@ -30,6 +33,8 @@ class ACEFileWriteException(ACEFileException): #{{{1
 
 class ACEFile(): #{{{1
     dictEntries = QStringList()
+    _metadataValues = {}
+
     def __init__(self): #{{{2
         self.read()
         return
@@ -60,20 +65,20 @@ class ACEFile(): #{{{1
         return entryString
 
     def _readMetadata(self, file): #{{{2
-        if not file.seek(posPaddingOffset):
+        if not file.seek(positions['PaddingOffset']):
             raise IOError(errno.EIO, "Error seeking in file", dictionaryFile)
 
-        paddingOffset = self._bytesToInt(file.read(3))
+        self._metadataValues['PaddingOffset'] = self._bytesToInt(file.read(2))
 
-        if not file.seek(posEntryCount):
+        if not file.seek(positions['Unknown']):
             raise IOError(errno.EIO, "Error seeking in file", dictionaryFile)
 
-        entryCount = self._bytesToInt(file.read(2))
+        self._metadataValues['Unknown'] = file.read(1)
 
-        if not file.seek(16):
+        if not file.seek(positions['EntryCount']):
             raise IOError(errno.EIO, "Error seeking in file", dictionaryFile)
 
-        return (paddingOffset, entryCount)
+        self._metadataValues['EntryCount'] = self._bytesToInt(file.read(2))
 
     def _validateMetadata(self, file): #{{{2
         if not file.seek(0):
@@ -82,15 +87,18 @@ class ACEFile(): #{{{1
         bfr = file.read(16)
 
         if bfr[0:4] != '\x80\x00\x01\x01':
-            print "Fails 1"
             return False
 
-        if bfr[8:12] != '\x00\x03\x00\x10':
-            print "Fails 2"
+        if bfr[5] != '\x00':
+            return False
+
+        if bfr[8] != '\x00':
+            return False
+
+        if bfr[10:12] != '\x00\x10':
             return False
 
         if bfr[14:16] != '\x00\x00':
-            print "Fails 3"
             return False
 
         return True
@@ -107,7 +115,9 @@ class ACEFile(): #{{{1
         file.write('\x80\x00\x01\x01')
         file.write(self._intToBytes(fileSizeK * 4, 1))
         file.write(self._intToBytes(16 + dataSize, 3))
-        file.write('\x00\x03\x00\x10')
+        file.write('\x00')
+        file.write(self._metadataValues['Unknown'])
+        file.write('\x00\x10')
         file.write(self._intToBytes(len(self.dictEntries), 2))
         file.write('\x00\x00')
 
@@ -126,16 +136,16 @@ class ACEFile(): #{{{1
         if not file.open(QIODevice.ReadOnly):
             raise IOError(errno.EIO, "Cannot open file", dictionaryFile)
 
-        (paddingOffset, entryCount) = self._readMetadata(file)
+        self._readMetadata(file)
 
-        if not file.seek(posEntryStart):
+        if not file.seek(positions['EntryStart']):
             raise IOError(errno.EIO, "Error seeking in file", dictionaryFile)
 
-        while file.pos() < paddingOffset:
+        while file.pos() < self._metadataValues['PaddingOffset']:
             entryString = self._readEntry(file)
             self.dictEntries.append(entryString)
 
-        if len(self.dictEntries) != entryCount:
+        if len(self.dictEntries) != self._metadataValues['EntryCount']:
             raise ACEFileReadException('Entry count mismatch')
 
         file.close()
