@@ -9,7 +9,7 @@ from PyQt4.QtGui   import QAbstractItemView, QCompleter, QDialog, \
                           QVBoxLayout, QWidget
 from ACE_file      import ACEFile;
 
-version = '0.0.2'
+version = '0.0.3'
 
 class ACEAboutWindow(QDialog): #{{{1
     def __init__(self, parent): #{{{2
@@ -106,6 +106,9 @@ class ACEMainWindow(QWidget): #{{{1
         self._listView.addItems(self._dict.dictEntries)
 
     def saveChanges(self, checked): #{{{2
+        if self._maemo:
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+
         for entry in self._delList:
             pos = self._dict.dictEntries.indexOf(entry)
             self._dict.dictEntries.removeAt(pos)
@@ -117,6 +120,11 @@ class ACEMainWindow(QWidget): #{{{1
 
         call(['/usr/bin/killall', 'hildon-input-method'])
 
+        if self._maemo:
+            from PyQt4.QtMaemo5 import QMaemo5InformationBox
+            QMaemo5InformationBox.information(self, 'Dictionary saved', QMaemo5InformationBox.DefaultTimeout)
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+
     def setupMenu(self): #{{{2
         menu = QMenuBar()
 
@@ -127,7 +135,7 @@ class ACEMainWindow(QWidget): #{{{1
     def setupScreen(self): #{{{2
         self._listView = QListWidget()
         self._listView.setUniformItemSizes(True)
-        self._listView.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        self._listView.setSelectionMode(QAbstractItemView.MultiSelection)
         self._listView.setSortingEnabled(True)
 
         btnBox = QDialogButtonBox()
